# yl-app

一键生成基本flask项目骨架的工具

### 使用方法

#### 1、安装p
```
pip install yl-app
```
#### 2、创建项目骨架
```
mkdir demo
cd demo
yl-app flask-demo
```

![image](https://hbimg.huabanimg.com/d1d39b85b9841d682171a5b49786bdcdea74e607ecb26-4deb7f_fw658)